from .user import Account
from .pom import PROJECT_PKG_NAME as _project_pkg_name

import com_chery


db_session = com_chery.chery_pom_root.get_db_session(_project_pkg_name)


def get_all_accounts():
    accounts = db_session.query(Account).filter().limit(3).all()
    return accounts




PROJECT_PKG_VERSION = '0.0.5'

INCLUDE_FILES = [
    'user.py',
    'user_service.py',
]

PROJECT_PKG_NAME = 'chery_user_model_service'
PYPI_PKG_NAME = ('com_' + PROJECT_PKG_NAME).replace('_', '-')
CHERY_POM_ROOT_REQUIRED_VERSION = '0.0.1'


if __name__ == '__main__':
    import chery_pom_tool
    chery_pom_tool.build_and_upload(
        PROJECT_PKG_NAME,
        PYPI_PKG_NAME,
        CHERY_POM_ROOT_REQUIRED_VERSION,
        PROJECT_PKG_VERSION,
        INCLUDE_FILES,
    )



import sqlalchemy as db
from extension_db import Base, ModelMixin


class Account(Base, ModelMixin):
    __tablename__ = "accounts"
    __table_args__ = (db.PrimaryKeyConstraint("id", name="account_pkey"), db.Index("account_email_idx", "email"))

    id = db.Column(db.UUID, server_default=db.text("uuid_generate_v4()"))
    name = db.Column(db.String(255), nullable=False)
    nickname = db.Column(db.String(255), nullable=False)
    email = db.Column(db.String(255), nullable=False)
    real_email = db.Column(db.String(255), nullable=True)  # 新增real_email
    password = db.Column(db.String(255), nullable=True)
    password_salt = db.Column(db.String(255), nullable=True)
    avatar = db.Column(db.String(255))
    interface_language = db.Column(db.String(255))
    interface_theme = db.Column(db.String(255))
    timezone = db.Column(db.String(255))
    last_login_at = db.Column(db.DateTime)
    last_login_ip = db.Column(db.String(255))
    last_active_at = db.Column(db.DateTime, nullable=False, server_default=db.text("CURRENT_TIMESTAMP(0)"))
    status = db.Column(db.String(16), nullable=False, server_default=db.text("'active'::character varying"))
    initialized_at = db.Column(db.DateTime)
    created_at = db.Column(db.DateTime, nullable=False, server_default=db.text("CURRENT_TIMESTAMP(0)"))
    updated_at = db.Column(db.DateTime, nullable=False, server_default=db.text("CURRENT_TIMESTAMP(0)"))


from setuptools import setup, find_packages

setup(
    name='com-chery-user-model-service',
    version='0.0.5',
    packages=[
        'com_chery',
        'com_chery.chery_user_model_service',
    ],
    include_package_data=True,
    install_requires=[
        'requests',
        'python-dotenv',
    ],
    description='temp package, will be deleted later 2024-12-24',
    # long_description=open('README.md').read(),
    # long_description_content_type='text/markdown',
    # author='Your Name',
    # author_email='your.email@example.com',
    # url='https://example.com/com_example_root',
    classifiers=[
        'Programming Language :: Python :: 3',
        'Operating System :: OS Independent',
    ],
)